import { FastifyPluginAsync } from 'fastify';
import { readFileSync, readdirSync } from 'fs';
import path from 'path';
import { parser } from '../server';

const routes: FastifyPluginAsync = async (server) => {
    try {
     const userConfig = parser.parse(
        readFileSync(path.join(path.resolve(path.dirname('')), 'config.json'), {
          encoding: 'utf-8',
        }),
      );
      const customPages = readdirSync(path.join(path.resolve(path.dirname('')),"themes",userConfig.theme)).filter(f=>f.endsWith(".ejs")&&f!="index.ejs")
      customPages.forEach(page => {
        console.info("Loaded "+page)
        server.get(`/${page.replace(".ejs","")}`,{},async function(req,res){
            return res.view(page,{title:userConfig.title,subtitle:userConfig.subtitle})
        })
      });
    } catch (error) {
      console.error('Error parsing userconfig! Parser threw the following error:');
      console.error(error);
      console.error('Check your config.json file!');
      process.exit(1);
    }
};

export default routes;
