// import { Type } from '@sinclair/typebox';
import { FastifyPluginAsync } from 'fastify';
import { readFileSync } from 'fs';
import path from 'path';
import { parser } from '../server';
import { findMastodonUser, getLatestMastodonPost } from 'api/mastodon';

const routes: FastifyPluginAsync = async (server) => {
  server.get('/', {}, async function (req, res) {
    let userConfig;
    try {
      userConfig = parser.parse(
        readFileSync(path.join(path.resolve(path.dirname('')), 'config.json'), {
          encoding: 'utf-8',
        }),
      );
    } catch (error) {
      console.error('Error parsing userconfig! Parser threw the following error:');
      console.error(error);
      console.error('Check your config.json file!');
      process.exit(1);
    }
    try {
      let mastodon = undefined;
      if(userConfig.mastodon != null && userConfig.mastodon.host != undefined && userConfig.mastodon.username != undefined){
        let user = userConfig.mastodon.username
        if(/\w/gm.test(user)){
          // TODO: save ID to config
          user = await findMastodonUser(userConfig.mastodon.username,userConfig.mastodon.host);
        }
        mastodon = await getLatestMastodonPost(user,userConfig.mastodon.host)
      }
    return res.view('index.ejs',{title:userConfig.title,subtitle:userConfig.subtitle,mastodon});
    } catch (error) {
      console.error("Error while rendering index! Got following error:")
      console.error(error)
    }
  });
};

export default routes;
